sqlmesh.core.constants API documentation

Edit on GitHub

# sqlmesh.core.constants

View Source

     1from __future__ import annotations
     2
     3import datetime
     4
     5SQLMESH = "sqlmesh"
     6
     7PROD = "prod"
     8"""Prod"""
     9DEV = "dev"
    10"""Dev"""
    11
    12SNAPSHOTS_PATH = "snapshots"
    13"""Snapshots path"""
    14DEFAULT_SNAPSHOT_TTL = "in 1 week"
    15"""Default snapshot TTL"""
    16DEFAULT_ENVIRONMENT_TTL = "in 1 week"
    17"""Default environment TTL"""
    18IGNORE_PATTERNS = [
    19    ".ipynb_checkpoints/*",
    20]
    21"""Ignore patterns"""
    22CACHE_PATH = ".cache"
    23"""Cache path"""
    24TABLE_INFO_CACHE = "table_info_cache"
    25"""Table info cache"""
    26DATA_VERSION_LIMIT = 10
    27"""Data version limit"""
    28DEFAULT_TIME_COLUMN_FORMAT = "%Y-%m-%d"
    29"""Default time column format"""
    30
    31EPOCH = datetime.date(1970, 1, 1)
    32
    33DEFAULT_MAX_LIMIT = 1000
    34"""The default maximum row limit that is used when evaluating a model."""

PROD = 'prod'

Prod

DEV = 'dev'

Dev

SNAPSHOTS_PATH = 'snapshots'

Snapshots path

DEFAULT_SNAPSHOT_TTL = 'in 1 week'

Default snapshot TTL

DEFAULT_ENVIRONMENT_TTL = 'in 1 week'

Default environment TTL

IGNORE_PATTERNS = ['.ipynb_checkpoints/*']

Ignore patterns

CACHE_PATH = '.cache'

Cache path

TABLE_INFO_CACHE = 'table_info_cache'

Table info cache

DATA_VERSION_LIMIT = 10

Data version limit

DEFAULT_TIME_COLUMN_FORMAT = '%Y-%m-%d'

Default time column format

DEFAULT_MAX_LIMIT = 1000

The default maximum row limit that is used when evaluating a model.